@@ -254,7 +254,7 @@ def symmetrize(Clth, mode="arithm"):
       if geo return C_l1l2 = sqrt( |Cl1 Cl2 |)
       if arithm return C_l1l2 = (Cl1 + Cl2)/2
     """
-
+    
     if mode == "geo":
         return np.sqrt(np.abs(np.outer(Clth, Clth)))
     if mode == "arithm":
@@ -416,6 +416,37 @@ def extract_TTTEEE_mbb(mbb_inv):
     
     return mbb_inv_array
 
+def extract_EEEBBB_mbb(mbb_inv):
+    """this routine extract the E and B part of the mode coupling matrix
+
+    Parameters
+    ----------
+
+    mbb_inv: 2d array
+        the inverse spin0 and 2 mode coupling matrix
+    """
+
+    mbb_inv_array = so_mcm.coupling_dict_to_array(mbb_inv)
+    mbb_array = np.linalg.inv(mbb_inv_array)
+    nbins = int(mbb_array.shape[0] / 9)
+
+    mbb_array_select = np.zeros((4*nbins, 4*nbins))
+    # EE
+    mbb_array_select[0*nbins:1*nbins, 0*nbins:1*nbins] = mbb_array[5*nbins:6*nbins, 5*nbins:6*nbins]
+    # EB
+    mbb_array_select[1*nbins:2*nbins, 1*nbins:2*nbins] = mbb_array[6*nbins:7*nbins, 6*nbins:7*nbins]
+    # BE
+    mbb_array_select[2*nbins:3*nbins, 2*nbins:3*nbins] = mbb_array[7*nbins:8*nbins, 7*nbins:8*nbins]
+    # BB
+    mbb_array_select[3*nbins:4*nbins, 3*nbins:4*nbins] = mbb_array[8*nbins:9*nbins, 8*nbins:9*nbins]
+    # EE-BB
+    mbb_array_select[0*nbins:1*nbins, 3*nbins:4*nbins] = mbb_array[5*nbins:6*nbins, 8*nbins:9*nbins]
+    # BB-EE
+    mbb_array_select[3*nbins:4*nbins, 0*nbins:1*nbins] = mbb_array[8*nbins:9*nbins, 5*nbins:6*nbins]
+
+    mbb_inv_array = np.linalg.inv(mbb_array_select)
+
+    return mbb_inv_array
 
 
 def cov2corr(cov, remove_diag=True):
@@ -506,7 +537,7 @@ def g(a, b, c, d, ns):
     return result
 
 
-def chi(alpha, gamma, beta, eta, ns, ls, Dl, DNl, id="TTTT"):
+def chi(alpha, gamma, beta, eta, ns, Dl, DNl, id="TTTT"):
     """doc not ready yet
     """
     exp_alpha, f_alpha = alpha.split("_")
@@ -526,7 +557,7 @@ def chi(alpha, gamma, beta, eta, ns, ls, Dl, DNl, id="TTTT"):
     return chi
 
 
-def chi_planck(alpha, gamma, beta, eta, ns, ls, Dl, DNl, id="TTTT"):
+def chi_planck(alpha, gamma, beta, eta, ns, Dl, DNl, id="TTTT"):
     """doc not ready yet
         """
     exp_alpha, f_alpha = alpha.split("_")
